@@ -1,9 +1,12 @@
 """
 """
 
-__version__ = '0.1.6-2'
+__version__ = '0.1.8'
 __author__ = 'Oliver Lindemann'
 
+DEVELOPER_VERSION = False # include preliminary features
+
+
 import sys as _sys
 from . import consts
 from .json_settings import JSONSettings as _JSONSettings
@@ -18,4 +21,7 @@ if _sys.version_info[0] != 3 or _sys.version_info[1]<5:
 
 settings = _JSONSettings(appname=consts.APPNAME.replace(" ", "_").lower(),
                          settings_file_name="settings.json",
-                         defaults= {"base_directory": None})
+                         defaults= {"recent_dirs": []})
+
+if DEVELOPER_VERSION:
+    __version__ += "-dev"
\ No newline at end of file
